==> release.12.0.73.1.tgz: cgi-cpn/multitag/prontus_multitag_limpia_cache.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Borra todos los archivos generados en el cache de multitag
# ---------------------------------------------------------------
# LLAMADAS A ARCHIVOS EXTERNOS.
# ------------------------------
# NO
# ---------------------------------------------------------------
# INVOCACIONES ACEPTADAS.
# ------------------------
# solo cli
# ---------------------------------------------------------------
# PLANTILLAS HTML UTILIZADAS.
# ----------------------------
# Ninguna
# ---------------------------------------------------------------
# ---------------------------------------------------------------
# TABLAS UTILIZADAS.
# -------------------
# NINGUNA
# ---------------------------------------------------------------
# -------------------------------BEGIN SCRIPT---------------
# ---------------------------------------------------------------
# DIRECTIVAS DE COMPILACION.
# ---------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
    $pathLibsProntus =~ s/\/[^\/]+$//;
    unshift(@INC,$pathLibsProntus);
}

use lib_prontus;
use lib_stdlog;
&lib_stdlog::set_stdlog($0, 51200);

use prontus_varglb; &prontus_varglb::init();
use glib_fildir_03;

main: {
    &lib_prontus::setUtf8();
    my $prontus_id = $ARGV[0];

    # Carga variables de configuracion.
    my $msg_load = &lib_prontus::load_config_by_id($prontus_id);
    if ($msg_load ne '') {
        print STDERR "Error: $msg_load\n";
        exit;
    }

    my $cache_dir = $prontus_varglb::DIR_SERVER . $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_SITE'} . $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_MULTITAG'};

    if (!(&glib_fildir_03::check_dir($cache_dir)) ) {
        print STDERR "No se puede crear el directorio de cache para multitag: [$cache_dir]";
    } else {
        unlink(glob("$cache_dir/*.html"));
    }
}

==> release.12.2.28.1.tgz: cgi-cpn/multitag/prontus_multitag_limpia_cache.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Borra todos los archivos generados en el cache de multitag
# ---------------------------------------------------------------
# LLAMADAS A ARCHIVOS EXTERNOS.
# ------------------------------
# NO
# ---------------------------------------------------------------
# INVOCACIONES ACEPTADAS.
# ------------------------
# solo cli
# ---------------------------------------------------------------
# PLANTILLAS HTML UTILIZADAS.
# ----------------------------
# Ninguna
# ---------------------------------------------------------------
# ---------------------------------------------------------------
# TABLAS UTILIZADAS.
# -------------------
# NINGUNA
# ---------------------------------------------------------------
# -------------------------------BEGIN SCRIPT---------------
# ---------------------------------------------------------------
# DIRECTIVAS DE COMPILACION.
# ---------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
    $pathLibsProntus =~ s/\/[^\/]+$//;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use File::Copy;
use glib_fildir_03;
use lib_utils;
##/libs##

main: {
    lib_utils::setUtf8();
    my $prontus_id = $ARGV[0];

    # Carga variables de configuracion.
    my $msg_load = lib_utils::load_config_by_id($prontus_id);
    if ($msg_load ne '') {
        print STDERR "Error: $msg_load\n";
        exit;
    }

    my $cache_dir = $prontus_varglb::DIR_SERVER . $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_SITE'} . $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_MULTITAG'};

    if (!(glib_fildir_03::check_dir($cache_dir)) ) {
        print STDERR "No se puede crear el directorio de cache para multitag: [$cache_dir]";
    } else {
        unlink(glob("$cache_dir/*.html"));
    }
}
